import 'package:json_annotation/json_annotation.dart';

part 'identity.g.dart';

@JsonSerializable()
class Identity {
  const Identity(
      {required this.firstNameICAO9303,
      this.givenNameICAO9303,
      required this.firstName,
      this.givenName});

  @JsonKey(name: "fn", required: true)
  final String firstName;

  @JsonKey(name: "gn", required: false)
  final String? givenName;

  /*
    Forename(s) of the holder transliterated using the same 
    convention as the one used in the holder’s machine 
    readable travel documents (such as the rules defined in 
    ICAO Doc 9303 Part 3).
    If the holder has no forenames, the field MUST be 
    skipped.

    Exactly 1 (one) non-empty field MUST be provided, only 
    including characters A-Z and <. Maximum length: 80 
    characters (as per ICAO 9303 specification).
  */
  @JsonKey(name: "fnt", required: true)
  final String firstNameICAO9303;

  @JsonKey(name: "gnt", required: false)
  final String? givenNameICAO9303;

  factory Identity.fromJson(Map<String, dynamic> json) =>
      _$IdentityFromJson(json);

  Map<String, dynamic> toJson() => _$IdentityToJson(this);
}
