import 'package:eudcc/certificates/valuesets/country.dart';
import 'package:eudcc/certificates/valuesets/vaccine.dart';
import 'package:eudcc/certificates/valuesets/target.dart';
import 'package:json_annotation/json_annotation.dart';

part 'vaccine.g.dart';

@JsonSerializable()
class Vaccine {
  @JsonKey(name: "tg", fromJson: targetFromJson, toJson: targetToJson)
  final Target target;

  @JsonKey(name: "vp", fromJson: prophylaxisFromJson, toJson: prophylaxisToJson)
  final Prophylaxis prophylaxis;

  @JsonKey(name: "ci")
  final String identifier;

  @JsonKey(name: "co", fromJson: countryFromJson, toJson: countryToJson)
  final Country country;

  @JsonKey(name: "mp", fromJson: productFromJson, toJson: productToJson)
  final Product product;

  @JsonKey(
      name: "ma", fromJson: manufacturerFromJson, toJson: manufacturerToJson)
  final Manufacturer manufacturer;

  @JsonKey(name: "dn")
  final int doses;

  @JsonKey(name: "sd")
  final int totalDoses;

  @JsonKey(name: "dt")
  final DateTime date;

  @JsonKey(name: "is")
  final String issuer;

  const Vaccine(
      this.target,
      this.prophylaxis,
      this.identifier,
      this.country,
      this.product,
      this.manufacturer,
      this.doses,
      this.totalDoses,
      this.date,
      this.issuer);

  factory Vaccine.fromJson(Map<String, dynamic> json) =>
      _$VaccineFromJson(json);

  Map<String, dynamic> toJson() => _$VaccineToJson(this);
}
