import 'package:eudcc/certificates/valuesets/valueset.dart';

import 'valueset.dart';

class CountrySet extends ValueSet<Country> {
  static final CountrySet _singleton = CountrySet._internal();

  factory CountrySet() {
    return _singleton;
  }

  CountrySet._internal()
      : super("specs/ehn-dcc-valuesets/country-2-codes.json");

  @override
  Country buildUnknown(String name, String key) {
    if (key.length > 2) {
      // Support for UNHCR or other NGO
      return Country(key, "", true, "", "");
    }
    return Country(name, "", false, "", "");
  }

  @override
  Country buildFromJson(Map<String, dynamic> json) {
    return Country.fromJson(json);
  }
}

Country countryFromJson(String code) {
  return CountrySet().lookup(code);
}

String countryToJson(Country co) {
  return co.key;
}

class Country extends Value {
  Country(String? displayName, String? language, bool? active, String? version,
      String? urn)
      : super(displayName, language, active, version, urn);

  factory Country.fromValue(Value v) =>
      Country(v.displayName, v.language, v.active, v.version, v.urn);

  factory Country.fromJson(Map<String, dynamic> json) =>
      Country.fromValue(Value.fromJson(json));
}
