import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:json_annotation/json_annotation.dart';

part 'valueset.g.dart';

abstract class ValueSet<T extends Value> {
  final String _asset;

  ValueSet(this._asset);

  T buildUnknown(String name, String key);

  T buildFromJson(Map<String, dynamic> json);

  Map<String, T> data = {};

  T lookup(String key) {
    if (data.containsKey(key)) {
      return data[key]!;
    }
    // Provide fallback country
    var t = buildUnknown("unknown (key:$key)", key);
    t.setKey(key);
    return t;
  }

  Future<void> load() async {
    var m = jsonDecode(await rootBundle.loadString(_asset));
    for (MapEntry e in m["valueSetValues"].entries) {
      var v = buildFromJson(e.value);
      v.setKey(e.key);
      data[e.key] = v;
    }
  }
}

@JsonSerializable()
class Value {
  @JsonKey(name: "display", required: true)
  final String? displayName;

  @JsonKey(ignore: true)
  late String key;

  @JsonKey(name: "lang")
  final String? language;

  @JsonKey(name: "active")
  final bool? active;

  @JsonKey(name: "version")
  final String? version;

  @JsonKey(name: "system")
  final String? urn;

  Value(this.displayName, this.language, this.active, this.version, this.urn);

  factory Value.fromJson(Map<String, dynamic> json) => _$ValueFromJson(json);

  Map<String, dynamic> toJson() => _$ValueToJson(this);

  Value setKey(String key) {
    this.key = key;
    return this;
  }
}
