import 'package:eudcc/certificates/recovery.dart';
import 'package:eudcc/eudcc.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  test('parse recovery without dataSets', () {
    var json = {
      "tg": "840539006",
      "fr": "2021-05-18",
      "co": "UNHCR",
      "is": "Central University Hospital",
      "df": "2021-05-29",
      "du": "2021-11-14",
      "ci": "URN:UVCI:01:NL:187/37512422923"
    };
    var id = Recovery.fromJson(json);
    expect(id.target.key, "840539006");
    expect(id.positive, DateTime.utc(2021, 5, 18));
    expect(id.until, DateTime.utc(2021, 11, 14));
    expect(id.from, DateTime.utc(2021, 5, 29));
    expect(id.country.key, "UNHCR");
    expect(id.issuer, "Central University Hospital");
    expect(id.identifier, "URN:UVCI:01:NL:187/37512422923");
  });
  test('parse recovery with dataSets', () async {
    TestWidgetsFlutterBinding.ensureInitialized();
    await EUDigitalCovidCertificateFactory().loadDataset(null);

    var json = {
      "tg": "840539006",
      "fr": "2021-05-18",
      "co": "UNHCR",
      "is": "Central University Hospital",
      "df": "2021-05-29",
      "du": "2021-11-14",
      "ci": "URN:UVCI:01:NL:187/37512422923"
    };
    var id = Recovery.fromJson(json);
    expect(id.target.displayName, "COVID-19");
    expect(id.country.displayName, "UNHCR");
  });
}
