import 'package:eudcc/certificates/test.dart';
import 'package:eudcc/eudcc.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  test('parse test without dataSets', () {
    var json = {
      "tg": "840539006",
      "tt": "LP217198-3",
      "nm": "ELITechGroup, SARS-CoV-2 ELITe MGB® Kit",
      "sc": "2021-08-20T12:03:12+02:00",
      "tr": "260415000",
      "tc": "Test centre west region 245",
      "co": "CZ",
      "is": "North-West region health authority",
      "ci": "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B"
    };
    var id = Test.fromJson(json);
    expect(id.target.key, "840539006");
    expect(id.type.key, "LP217198-3");
    expect(id.name, "ELITechGroup, SARS-CoV-2 ELITe MGB® Kit");
    expect(id.date, DateTime.utc(2021, 8, 20, 10, 03, 12));
    expect(id.facility, "Test centre west region 245");
    expect(id.country.key, "CZ");
    expect(id.issuer, "North-West region health authority");
    expect(id.identifier, "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B");
  });
  test('parse vaccine with dataSets', () async {
    TestWidgetsFlutterBinding.ensureInitialized();
    await EUDigitalCovidCertificateFactory().loadDataset(null);

    var json = {
      "tg": "840539006",
      "tt": "LP217198-3",
      "ma": "344",
      "sc": "2021-08-20T12:03:12+02:00",
      "tr": "260415000",
      "tc": "Test centre west region 245",
      "co": "CZ",
      "is": "North-West region health authority",
      "ci": "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B"
    };
    var id = Test.fromJson(json);
    expect(id.target.displayName, "COVID-19");
    expect(id.type.displayName, "Rapid immunoassay");
    expect(id.manufacturer!.displayName,
        "SD BIOSENSOR Inc, STANDARD F COVID-19 Ag FIA");
    expect(id.country.displayName, "Czechia");
  });
}
