import 'package:eudcc/certificates/vaccine.dart';
import 'package:eudcc/eudcc.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  test('parse vaccine without dataSets', () {
    var json = {
      "tg": "840539006",
      "vp": "1119349007",
      "mp": "EU/1/20/1528",
      "ma": "ORG-100030215",
      "dn": 1,
      "sd": 2,
      "dt": "2021-03-28",
      "co": "CZ",
      "is": "Ministry of Health of the Czech Republic",
      "ci": "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B"
    };
    var id = Vaccine.fromJson(json);
    expect(id.target.key, "840539006");
    expect(id.prophylaxis.key, "1119349007");
    expect(id.product.key, "EU/1/20/1528");
    expect(id.manufacturer.key, "ORG-100030215");
    expect(id.doses, 1);
    expect(id.totalDoses, 2);
    expect(id.country.key, "CZ");
    expect(id.issuer, "Ministry of Health of the Czech Republic");
    expect(id.identifier, "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B");
  });
  test('parse vaccine with dataSets', () async {
    TestWidgetsFlutterBinding.ensureInitialized();
    await EUDigitalCovidCertificateFactory().loadDataset(null);

    var json = {
      "tg": "840539006",
      "vp": "1119349007",
      "mp": "EU/1/20/1528",
      "ma": "ORG-100030215",
      "dn": 1,
      "sd": 2,
      "dt": "2021-03-28",
      "co": "CZ",
      "is": "Ministry of Health of the Czech Republic",
      "ci": "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B"
    };
    var id = Vaccine.fromJson(json);
    expect(id.target.displayName, "COVID-19");
    expect(id.prophylaxis.displayName, "SARS-CoV-2 mRNA vaccine");
    expect(id.product.displayName, "Comirnaty");
    expect(id.manufacturer.displayName, "Biontech Manufacturing GmbH");
    expect(id.doses, 1);
    expect(id.totalDoses, 2);
    expect(id.country.displayName, "Czechia");
    expect(id.issuer, "Ministry of Health of the Czech Republic");
    expect(id.identifier, "URN:UVCI:01:AT:10807843F94AEE0EE5093FBC254BD813#B");
  });
}
